#ifndef GENERIC_FI_H
#define GENERIC_FI_H

/* Compilers may use another function within the assert macro to exit the 
 * program. QAC thus does not see an "exit" function and assumes the 
 * function returns, which it does not.
 * The below pragma tells QAC the compiler supplied function does not
 * return.
 */

/* examples - GCC, ICC, BCC 3.1, BCC 5.5, CYGWIN gcc, Watcom 1.6, Diab 5.6*/
#pragma PRQA_NO_RETURN __assert_fail
#pragma PRQA_NO_RETURN __assert_perror_fail
#pragma PRQA_NO_RETURN __assert

/* SDCC, BCC 5.5, Digital Mars DM 8.4, LCC, Watcom 1.6, Fujitsu F2MM,FR */
#pragma PRQA_NO_RETURN _assert

/* HI-TECH PCCLite */
#pragma PRQA_NO_RETURN _fassert

/* DJGPP, D.J.Delorie gcc DOS port */
#pragma PRQA_NO_RETURN __dj_assert

/* Watcom 1.6, MSVS 08 */
#pragma PRQA_NO_RETURN _wassert
#pragma PRQA_NO_RETURN __wassert
#pragma PRQA_NO_RETURN _assert99
#pragma PRQA_NO_RETURN _wassert99
#pragma PRQA_NO_RETURN __assert99
#pragma PRQA_NO_RETURN __wassert99

/* Renesas M32R compiler */
#pragma PRQA_NO_RETURN _Assert

/* NEC 78K0 series 16bit compiler */
#pragma PRQA_NO_RETURN __assertfail
#pragma PRQA_NO_RETURN __assertfail_n
#pragma PRQA_NO_RETURN __assertfail_f


/* Depending on the code that the compiler maker uses within the assert macro,
 * QAC may issue warnings. It is also possible that when the NDEBUG macro is used
 * to suppress the assertion code, QAC may issue a "no side-effects" warning.
 * To eliminate these, we turn off all warnings for the assert macro.
 */
#pragma PRQA_MACRO_MESSAGES_OFF "assert"


/* Any other items that may be required in a "force-include" file should
 * be placed below.
 */

/* Wind River (Diab) compiler v5.6 intrinsics */
int __builtin_expect(long exp, long c);
char *alloca(int);
char *__alloca(int);
extern void __ERROR__(char *, ...);



void __ffi (int var);
void __mar (long long a);
void __mia (int a, int b);
void __miabb (int a, int b);
void __miabt (int a, int b);
void __miaph (int a, int b);
void __miatb (int a, int b);
void __miatt (int a, int b);
long long __mra (void);
void __qadd (int a, int b);
void __qdadd (int a, int b);
void __qdsub (int a, int b);
void __qsub (int a, int b);
void __smlabb (int a, int b, int c);
void __smlabt (int a, int b, int c);
void __smlalbb (long long a, int b, int c);
void __smlalbt (long long a, int b, int c);
void __smlaltb (long long a, int b, int c);
void __smlaltt (long long a, int b, int c);
void __smlatb (int a, int b, int c);
void __smlatt (int a, int b, int c);
void __smlawb (int a, int b, int c);
void __smlawt (int a, int b, int c);
void __smulbb (int a, int b);
void __smulbt (int a, int b);
void __smultb (int a, int b);
void __smultt (int a, int b);
void __smulwb (int a, int b);
void __smulwt (int a, int b);
#else
#error "Multiple include"
#endif  /* ifndef GENERIC_FI_H */



